@@ -57,9 +57,11 @@ OfflineMode="False"
 #OldOfflineMode="False" #restore original state after recording
 DelayStart=0
 interval=0
+GraphStart=0
 
 #arrays, indexes, lenghts
-arrDataLen=4680 #(1 value/10sec for 13h), 6*13*60
+#arrDataLen=4680 #(1 value/10sec for 13h), 6*13*60
+arrDataLen=8640 #(1 value/10sec for 24h), 6*24*60
 arrData=[[0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen] #[0]=time [1]=X, [2]=Y, [3]=X deriv, [4]=Y deriv
 arrDataTemp=[0, 0, 0] #[0]=unused, [1]=X, [2]=Y
 arrDataIndex=0
