@@ -124,19 +124,26 @@ def EditUserName():
 #  Gets called every second,
 ###########################################################################
 def TimerLoop():
-    global RecordWindowGraph
-    
+    global RecordWindowGraph    
 #    Show_passed_time("TimerLoop start")
-
     r=GetSensorData() #(interval: sampling*sample_smoothing*value_smoothing)
     if(r==1):
         WriteIntoLogFile()
         ProcessData() 
+        
+        Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
+        data.GraphStart=max(Pixels-779, 0)
+#        print data.GraphStart      
+        
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
-        RecordWindowGraph.update() #show RecordWindowGraph    
-    
-    RecordWindow.UpdateScreen()    
+        RecordWindowGraph.update() #show RecordWindowGraph          
     
+#        print data.arrDataIndex
+        if(data.arrDataIndex==data.arrDataLen-1): 
+            print "Stopped, array is full"
+            QtGui.QMessageBox.warning(RecordWindow, 'Memory is full!', "You reached the end of the recording capacity (24h)!\nThe recording stops now.", QtGui.QMessageBox.Ok)
+            RecordWindow.ToggleMeasurement()
+    RecordWindow.UpdateScreen()        
 #    Show_passed_time("TimerLoop end")
 
   
@@ -485,7 +492,7 @@ class frmRecordWindow(QMainWindow):
 #        self.ui.lblTrigger.setText(str(data.trigger))
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
         self.ui.bStop.setIcon(QIcon(data.app_path+"img/"+"krec2.png"))
-        self.ui.bStop.setText("Stop recording")
+        self.ui.bStop.setText("Stop")
 
         self.UpdateScreen()
         
@@ -499,7 +506,7 @@ class frmRecordWindow(QMainWindow):
     def UpdateScreenStart(self):
 #        print "UpdateScreenStart"
         self.ui.lblLogfile.setText(str(data.logfilename))
-        t= t=strftime("%d. %b %Y %H:%M:%S", data.StartTime)
+        t= t=strftime("%d. %b. %Y %H:%M:%S", data.StartTime)
         self.ui.lblStarttime.setText(t)
 #        self.ui.lblSamples_Taken.setText("0")
         self.ui.lblElapsedTime.setText("")
@@ -546,7 +553,7 @@ class frmRecordWindow(QMainWindow):
 #        self.ui.lblStarttime.setText("(Stopped)")
         self.ui.lblSamples_Taken.setText(str(data.values_total)+" (Stopped)")
         self.ui.bStop.setIcon(QIcon(data.app_path+"img/"+"krec.png"))
-        self.ui.bStop.setText("Start recording")
+        self.ui.bStop.setText("Start")
         
         
         
@@ -614,18 +621,20 @@ class frmRecordWindow(QMainWindow):
 
 
     def AskKeepRecord(self):
-    #check if user wants to keep this record
-        reply = QtGui.QMessageBox.question(self, 'Keep this Record?', "Do you want to keep this Record?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
-        if reply == QtGui.QMessageBox.No:
+        if(data.QuickMode==0): #check if user wants to keep this record        
+            reply = QtGui.QMessageBox.question(self, 'Keep this Record?', "Do you want to keep this Record?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+            if reply == QtGui.QMessageBox.No:
+                print "Delete logfile: "+data.logfilename
+                os.remove(data.logfolder+data.logfilename)
+            else:
+                data.lastlogfile=data.logfilename
+    #            print "lastlogfile:",  data.lastlogfile
+                config.set('main', 'lastlogfile', str(data.lastlogfile))                   
+    #            self.EditNote() #request adding a note
+                ChangeNoteInFile() #rewrite log file (only do when recording is stopped!)
+        else: #quick mode, delete file anyway
             print "Delete logfile: "+data.logfilename
             os.remove(data.logfolder+data.logfilename)
-        else:
-            data.lastlogfile=data.logfilename
-#            print "lastlogfile:",  data.lastlogfile
-            config.set('main', 'lastlogfile', str(data.lastlogfile))   
-            
-#            self.EditNote() #request adding a note
-            ChangeNoteInFile() #rewrite log file (only do when recording is stopped!)
 
 
     def EditNote(self):
@@ -676,9 +685,10 @@ class frmViewWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bEditNote, QtCore.SIGNAL("clicked()"), self.EditNote)
         QtCore.QObject.connect(self.ui.bLeft, QtCore.SIGNAL("clicked()"), self.goLeft)
         QtCore.QObject.connect(self.ui.bRight, QtCore.SIGNAL("clicked()"), self.goRight)
+#        QtCore.QObject.connect(self.ui.SlrScroll,SIGNAL("valueChanged(int)"),self.SliderMoved)
         
-        self.ui.bLeft.hide() #not yet used
-        self.ui.bRight.hide() #not yet used
+#        self.ui.bLeft.hide() #not yet used
+#        self.ui.bRight.hide() #not yet used
         
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bLast.setIcon(QIcon(data.app_path+"img/"+"arrow-left-double.png"))
@@ -750,8 +760,33 @@ class frmViewWindow(QMainWindow):
         else:
             self.ui.bNext.setEnabled(True)
             self.ui.bLast.setEnabled(True)
+            
+            
+                        
+        #scroll bar
+#        Xscale=data.arrXscale[data.Xscale]
+#        Pixels=data.arrDataIndex/Xscale
+##        print Xscale,  Pixels
+#        if(Pixels>775): 
+#            self.ui.SlrScroll.setEnabled(True)
+##            self.ui.SlrScroll.setMaxValue=Pixels-775     
+#        else: 
+#            self.ui.SlrScroll.setEnabled(False)
+#            self.ui.SlrScroll.setValue(0)
+#        self.SliderMoved()
+#        print self.ui.SlrScroll.value()
 
 
+        Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
+#        data.GraphStart=min(data.GraphStart+360, max(Pixels-775, 0))
+#        print data.GraphStart
+        if(data.GraphStart<max(Pixels-779, 0)): self.ui.bRight.setEnabled(True)
+        else: self.ui.bRight.setEnabled(False)
+        if(data.GraphStart>0): self.ui.bLeft.setEnabled(True)
+        else: self.ui.bLeft.setEnabled(False)
+            
+            
+            
 
     def ShowLogFile(self):
         r=OpenLogFile()    
@@ -761,9 +796,14 @@ class frmViewWindow(QMainWindow):
 #            closeEvent(0)
             self.OpenRecord()
             return
+        elif(r==3): #file is corrupted => draw empty graph
+            QtGui.QMessageBox.warning(self, 'File corrupded!', "The data in the record file\n"+data.logfilename+"\nis invalid!\nNo data loaded.", QtGui.QMessageBox.Ok)
         LoadFileList()
         ProcessData()
         data.Xscale=1 #default zoom level
+#        data.GraphStart=0        
+        Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
+        data.GraphStart=max(Pixels-779, 0)
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
         ViewWindowGraph = ViewWindowCanvas(self)
         ViewWindowGraph.show()
@@ -788,14 +828,22 @@ class frmViewWindow(QMainWindow):
         self.ui.bZoomOut.setEnabled(True)
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
+#        data.GraphStart=0
+        Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
+        data.GraphStart=max(Pixels-779, 0)
         self.update()
+        self.UpdateScreen()
 
     def ZoomOut(self):
-        r=Zoom(-1)
+        Zoom(-1)
         self.ui.bZoomIn.setEnabled(True)
         if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
         else: self.ui.bZoomOut.setEnabled(True)
+#        data.GraphStart=0
+        Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
+        data.GraphStart=max(Pixels-779, 0)
         self.update()
+        self.UpdateScreen()
         
         
 
@@ -810,11 +858,35 @@ class frmViewWindow(QMainWindow):
         self.UpdateScreen()
         
         
+#    def SliderMoved(self):
+#        s=self.ui.SlrScroll.value()
+#        Xscale=data.arrXscale[data.Xscale]
+#        Pixels=data.arrDataIndex/Xscale
+#        data.GraphStart=(Pixels-775)*s/100
+#        print s,  data.GraphStart,  Pixels
+#        data.ChangesInGraph=1 #Make sure it only gets refreshed once
+#        self.update()
+#        self.UpdateScreen()
+        
+        
+        
     def goLeft(self):
-        pass
+        Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
+        data.GraphStart=max(data.GraphStart-600, 0)
+#        print data.GraphStart                
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
+        self.update()
+        self.UpdateScreen()
+        
         
     def goRight(self):
-        pass
+        Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
+        data.GraphStart=min(data.GraphStart+600, max(Pixels-779, 0))
+#        print data.GraphStart        
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
+        self.update()
+        self.UpdateScreen()
+        
         
 
     def DeleteLogFile(self):
