@@ -142,31 +142,38 @@ def OpenLogFile():
         data.StartDate=string.replace(x, "Date: ",  "")
             
         data.MidnightTransitions=0
-        for line in file:
-#            print line
-            d=string.split(line,  ", ")
-            data.arrData[0][data.arrDataIndex]=d[0] #time
-            data.arrData[1][data.arrDataIndex]=int(d[1]) #X
-            data.arrData[2][data.arrDataIndex]=int(d[2]) #Y
-            
-            #check for transitions beond midnight:
-            if(data.arrDataIndex>0): 
-#                print data.arrDataIndex, data.arrData[0][data.arrDataIndex],  data.arrData[0][data.arrDataIndex-1]
-                if(data.arrData[0][data.arrDataIndex][:2]=="00" and  data.arrData[0][data.arrDataIndex-1][:2]=="23"):
-                    data.MidnightTransitions=data.MidnightTransitions+1
-#                    print data.arrDataIndex, "Midnight transition:",  data.MidnightTransitions
-            
-            data.arrDataIndex=data.arrDataIndex+1            
-            if(data.arrDataIndex==data.arrDataLen): 
-                print "Stopped, array is full, file is to big"
-                ret=1
-                break
+        try:
+            for line in file:
+    #            print line
+                d=string.split(line,  ", ")
+                data.arrData[0][data.arrDataIndex]=d[0] #time
+                data.arrData[1][data.arrDataIndex]=int(d[1]) #X
+                data.arrData[2][data.arrDataIndex]=int(d[2]) #Y
+                
+                #check for transitions beond midnight:
+                if(data.arrDataIndex>0): 
+    #                print data.arrDataIndex, data.arrData[0][data.arrDataIndex],  data.arrData[0][data.arrDataIndex-1]
+                    if(data.arrData[0][data.arrDataIndex][:2]=="00" and  data.arrData[0][data.arrDataIndex-1][:2]=="23"):
+                        data.MidnightTransitions=data.MidnightTransitions+1
+    #                    print data.arrDataIndex, "Midnight transition:",  data.MidnightTransitions
+                
+                data.arrDataIndex=data.arrDataIndex+1            
+                if(data.arrDataIndex==data.arrDataLen-1): 
+                    print "Stopped, array is full, file is to big"
+                    file.close()
+                    return 1 #File to long
+                    break
+        except:
+            print "File is corrupted"
+            file.close()
+            data.arrDataIndex=0
+            return 3 #corrupted file
     finally:
         file.close()
     
     print "Loaded",  str(data.arrDataIndex),  "lines"
 #    Show_passed_time("OpenLogFile End")
-    return ret
+    return 0
     
     
     
