@@ -145,15 +145,20 @@ def showGraph(self,  QtGui):
 
         Xscale=data.arrXscale[data.Xscale]
 #        print "Zoom level:",  data.Xscale
+        Pixels=data.arrDataIndex/Xscale
+        if(Pixels==0): Pixels=1 #prevent divisions by zero
+#        data.GraphStart=(Pixels-775)*s/100
 
-        x=data.arrDataIndex/Xscale
-        if(x>775): 
-            GraphStart=(x-775)*Xscale
-            if(data.debug==1): print "Graph too long, only show values",  GraphStart,  "to",  x
-        else: GraphStart=0
+#        print "GraphStart:",  data.GraphStart
+
+#        x=data.arrDataIndex/Xscale
+#        if(x>775): 
+#            data.GraphStart=(x-775)*Xscale
+#            if(data.debug==1): print "Graph too long, only show values",  data.GraphStart,  "to",  x
+#        else: data.GraphStart=0
             
         try:
-            t=string.split(data.arrData[0][GraphStart], ":")
+            t=string.split(data.arrData[0][data.GraphStart], ":")
             h0=int(t[0])
             m0=int(t[1])
         except:
@@ -184,11 +189,15 @@ def showGraph(self,  QtGui):
                     x=i+offset+k*decade/6-decade
                     paint.drawLine(x, data.Ysize, x, data.Ysize+5)  
                 h=(h0+int(i/decade)+1) % 24
-                paint.drawText(i+offset-20, data.Ysize+30, str(h)+":00") 
-                if(data.Xscale==0):
-                    paint.drawText(i+offset-20+decade/3, data.Ysize+30, str(h)+":20") 
-                    paint.drawText(i+offset-20+2*decade/3, data.Ysize+30, str(h)+":40") 
-        else: #test mode, do not show X scale as it is wrong
+                paint.drawText(i+offset-15, data.Ysize+30, str(h)+":00") 
+                if(data.Xscale==0): #add extra marks/numbers on biggest zoom level
+                    paint.drawText(i+offset-15+0.5*decade/3, data.Ysize+30, str(h)+":10") 
+                    paint.drawText(i+offset-15+decade/3, data.Ysize+30, str(h)+":20") 
+                    paint.drawText(i+offset-15+1.5*decade/3, data.Ysize+30, str(h)+":30") 
+                    paint.drawText(i+offset-15+2*decade/3, data.Ysize+30, str(h)+":40") 
+                    paint.drawText(i+offset-15+2.5*decade/3, data.Ysize+30, str(h)+":50") 
+                    for k in range(1, 12): paint.drawLine(x+decade/12*k, data.Ysize, x+decade/12*k, data.Ysize+5)
+        else: #test mode, do not show X scale as it is not calibrated
             paint.drawText(200, data.Ysize+20, "Test Mode")
 
 
@@ -202,33 +211,30 @@ def showGraph(self,  QtGui):
         paint.drawText(5, 15, str(data.Yscale))
 
 
-        #scroll bar border
-        GraphEnd=data.arrDataIndex/Xscale
-        if(GraphEnd<>0): SelectionStart=(GraphStart*100/GraphEnd)*779/100
-        else: SelectionStart=0
-        if(SelectionStart>0): #show scroll bar
+
+
+
+        #scroll bar 
+        start=data.GraphStart
+        end=start+775
+        if(data.debug==1): print start,  "(",  start*100/Pixels, "%)",  end,  "(",  end*100/Pixels, "%)", Pixels
+        if(start>0 or end<Pixels): #only draw if scroll bar needed
             paint.setPen(QtGui.QColor("gray"))
-            paint.drawRect(0,data.Ysize+37,781,7)
-            #Scroll bar
-    #        0%=1
-    #    100%=780
-    #        startpercent=GraphStart/data.arrDataIndex*100
-    #        print startpercent,  data.arrDataIndex
-#            print GraphStart,  GraphEnd,  GraphStart*100/GraphEnd, "%"
-#            print x
+            paint.drawRect(0,data.Ysize+37,776,7)
             paint.setPen(QtGui.QColor("white"))
             paint.setBrush(QtGui.QColor("white"))
-            paint.drawRect(SelectionStart,data.Ysize+38,780,5)
+            paint.drawRect(start*779/Pixels,data.Ysize+38,(end-start)*779/Pixels,5)
+
 
 
         #draw graph
         lastmove=0
-#        print GraphStart,  data.arrDataIndex-data.derivation,  Xscale
+#        print data.GraphStart,  data.arrDataIndex-data.derivation,  Xscale
         
-        end=data.arrDataIndex-GraphStart-data.derivation
+        end=data.arrDataIndex-data.GraphStart-data.derivation
         peak=0   
         for i in range(0,  end,  Xscale):
-            k=i+GraphStart
+            k=i+data.GraphStart
 
 
 
@@ -243,36 +249,16 @@ def showGraph(self,  QtGui):
    
     
     
-    
-#            if(1): #one or more movement for this pixel
-#                peak=abs(data.arrData[3][k])+abs(data.arrData[4][k])
             Y=peak*data.Yscale
             if(Y>=data.Ysize-17): 
                 Y=data.Ysize-17
-#                print "too big:",  Y,  peak*data.Yscale
-            #Draw movement line
-#            paint.setBrush(QtGui.QColor("yellow"))
             paint.drawLine(i/Xscale+1, data.Ysize-Y-1-15, i/Xscale+1, data.Ysize-1-15)  
             
             
-            #fill space between yellow movement lines
-#                if(k>lastmove+1):k
-#            print i,  end,  Xscale
             if(peak>data.trigger or i>=end-Xscale):
-#            if(peak>data.trigger):
 
 
 
-#                Show_passed_time("L 2")
-##                    1=10 sec
-#                    if((i-lastmove)>30*Xscale): color="#009100" #green
-#                    elif((i-lastmove)>15*Xscale): color="#005000" #dark green
-#                    t=(i-lastmove)*Xscale
-#                    print t,  30*Xscale
-#                    if(t>30): color="#009100" #green
-#                    elif(t>15): color="#005000" #dark green
-#                    else: color="#6D0000" #dark red 
-
                 x0=lastmove/Xscale+1
                 x1=i/Xscale-1
                 len=x1-x0
@@ -292,7 +278,6 @@ def showGraph(self,  QtGui):
 #                        print "=     Draw field",  x0,  x1,  data.Ysize,  color
                 lastmove=i
                 
-                
         
         if(peak>data.trigger): #if last value is over peak
             if(data.QuickMode==1 and (end-data.derivation)>data.last_beep): #quick mode for testing but only once pr move
